@@ -17,17 +17,18 @@ from pip._internal.req.constructors import install_req_from_line
 from pip._internal.resolution.resolvelib.factory import Factory
 from pip._internal.resolution.resolvelib.provider import PipProvider
 from pip._internal.utils.temp_dir import TempDirectory, global_tempdir_manager
+
 from tests.lib import TestData
 
 
 @pytest.fixture
-def finder(data: TestData) -> Iterator[PackageFinder]:
+def finder(data: TestData) -> PackageFinder:
     session = PipSession()
     scope = SearchScope([str(data.packages)], [], False)
     collector = LinkCollector(session, scope)
     prefs = SelectionPreferences(allow_yanked=False)
     finder = PackageFinder.create(collector, prefs)
-    yield finder
+    return finder
 
 
 @pytest.fixture
@@ -53,8 +54,8 @@ def preparer(finder: PackageFinder) -> Iterator[RequirementPreparer]:
 
 
 @pytest.fixture
-def factory(finder: PackageFinder, preparer: RequirementPreparer) -> Iterator[Factory]:
-    yield Factory(
+def factory(finder: PackageFinder, preparer: RequirementPreparer) -> Factory:
+    return Factory(
         finder=finder,
         preparer=preparer,
         make_install_req=install_req_from_line,
@@ -68,8 +69,8 @@ def factory(finder: PackageFinder, preparer: RequirementPreparer) -> Iterator[Fa
 
 
 @pytest.fixture
-def provider(factory: Factory) -> Iterator[PipProvider]:
-    yield PipProvider(
+def provider(factory: Factory) -> PipProvider:
+    return PipProvider(
         factory=factory,
         constraints={},
         ignore_dependencies=False,
